@@ -20,7 +20,7 @@ has storage => (is => 'rw', isa => 'HashRef',
                       unique_columns => ['name'],
                     },
                     dbxref =>{
-                      id_counter => 205,
+                      id_counter => 206,
                       column_names => [
                         'dbxref_id', 'accession', 'db_id',
                       ],
@@ -30,6 +30,7 @@ has storage => (is => 'rw', isa => 'HashRef',
                         [ 202, 'narrow', 101 ],
                         [ 203, 'cv_version', 101 ],
                         [ 204, 'replaced_by', 101 ],
+                        [ 205, 'consider', 101 ],
                       ],
                       unique_columns => ['accession', 'db_id'],
                     },
@@ -47,7 +48,7 @@ has storage => (is => 'rw', isa => 'HashRef',
                       unique_columns => ['name'],
                     },
                     cvterm => {
-                      id_counter => 405,
+                      id_counter => 406,
                       column_names => [
                         'cvterm_id', 'name', 'definition', 'cv_id',
                         'dbxref_id', 'is_relationshiptype', 'is_obsolete',
@@ -58,6 +59,7 @@ has storage => (is => 'rw', isa => 'HashRef',
                         [ 402, 'narrow', 'narrow', 301, 202, 0, 0],
                         [ 403, 'cv_version', 'cv_version', 302, 203, 0, 0],
                         [ 404, 'replaced_by', 'replaced_by', 303, 204, 0, 0],
+                        [ 405, 'consider', 'consider', 303, 205, 0, 0],
                       ],
                       unique_columns => ['name', 'cv_id'],
                     },
